## Script for Statistics
rm(list=ls())

setwd("") #insert directory of csv file
getwd()

# packages needed 
library(tidyverse) 
library(ggpubr)
library(dplyr)
library(ggfortify)
library(car)

#Read in data ####
datall <- read_csv("", skip = 1) #insert csv data file

datastats<- (datall[,-c(6:26, 28:37,40:53, 61:74)]) #exclude nutrient additions, OD, size&volume Data
datastats1 <-(datastats[,-c(16:22)]) #exclude Phase 2 data
datastats2 <-(datastats[-70,-c(9:15)]) #exclude Phase 1 data and sample 40 (Biovolume outlier)

datastats1$Medium <- factor(datastats1$Medium, levels=c("N&P low","N low","P low"))
datastats1$NP_medium <- factor(datastats1$NP_medium, levels=c("17.5","35","70"))
datastats1$Treatment <- factor(datastats1$Treatment, levels=c("Ctrl","P","N","N&P")) 
datastats1$Community <- as.factor(datastats1$Community) 
datastats1$Community <- factor(datastats1$Community, levels=c("1","2","3"))
datastats2$Medium <- factor(datastats2$Medium, levels=c("N&P low","N low","P low"))
datastats2$NP_medium <- factor(datastats2$NP_medium, levels=c("17.5","35","70"))
datastats2$Treatment <- factor(datastats2$Treatment, levels=c("Ctrl","P","N","N&P")) 
datastats2$Community <- as.factor(datastats2$Community) 
datastats2$Community <- factor(datastats2$Community, levels=c("1","2","3"))

datastats1$Total_Biovol <- rowSums(datastats1[,c("Syn_biovol_phase1","Ana_biovol_phase1", "Acu_biovol_phase1",
                                           "Mon_biovol_phase1","Cry_biovol_phase1","Nan_biovol_phase1",
                                           "Ste_biovol_phase1" )], na.rm=TRUE)
datastats2$Total_Biovol <- rowSums(datastats2[,c("Syn_biovol_phase2","Ana_biovol_phase2", "Acu_biovol_phase2",
                                           "Mon_biovol_phase2","Cry_biovol_phase2","Nan_biovol_phase2",
                                           "Ste_biovol_phase2")], na.rm=TRUE)


#METHODS - Correlation C and OD (Phase 2)####
#Community 1
#C1 <- subset(datastats2$C,  datastats2$Community == 1)
corr2OD1 <- subset(datastats2$"43",  datastats2$Community == 1)
corr2C1 <- subset(datastats2$C,  datastats2$Community == 1) 
cor.test(corr2OD1, corr2C1, method = "pearson") #corr.

#Community 2
#C2 <- subset(datastats2$C,  datastats2$Community == 2)
corr2OD2 <- subset(datastats2$"43",  datastats2$Community == 2)
corr2C2 <- subset(datastats2$C,  datastats2$Community == 2) 
cor.test(corr2C2, corr2OD2, method = "pearson") #corr.

#Community 2
#C3 <- subset(datastats2$C,  datastats2$Community == 3)
corr2OD3 <- subset(datastats2$"43",  datastats2$Community == 3)
corr2C3 <- subset(datastats2$C,  datastats2$Community == 3) 
cor.test(corr2C3, corr2OD3, method = "pearson") #corr.

#RESULTS - Correlation OD and biovolume (Phase 1)######
#Community 1 - 2 - 3
corrOD <- subset(datastats1$"21",  datastats1$Community == c("1","2","3"))
corrbiovol <- subset(datastats1$Total_Biovol,  datastats1$Community == c("1","2","3")) 
cor.test(corrOD, corrbiovol, method = "pearson") #R = 0.78

#RESULTS - Correlation OD and biovolume (Phase 2)####
#Community 1
#C1 <- subset(datastats2$C,  datastats2$Community == 1)
corr2OD1 <- subset(datastats2$"43",  datastats2$Community == 1)
corr2biovol1 <- subset(datastats2$Total_Biovol,  datastats2$Community == 1) 
cor.test(corr2OD1, corr2biovol1, method = "pearson") #R = 0.81

#Community 2
#C2 <- subset(datastats2$C,  datastats2$Community == 2)
corr2OD2 <- subset(datastats2$"43",  datastats2$Community == 2)
corr2biovol2 <- subset(datastats2$Total_Biovol,  datastats2$Community == 2) 
cor.test(corr2biovol2, corr2OD2, method = "pearson") #R = 0.84

#Community 2
#C3 <- subset(datastats2$C,  datastats2$Community == 3)
corr2OD3 <- subset(datastats2$"43",  datastats2$Community == 3)
corr2biovol3 <- subset(datastats2$Total_Biovol,  datastats2$Community == 3) 
cor.test(corr2biovol3, corr2OD3, method = "pearson") #R = 0.94


#RESULTS - Maximum mean proportion of out competed species - Phase 1 & 2####
###PHASE 1 - Sub-dominant species
datastatsMMP1 <- datastats1 %>% 
  pivot_longer(cols = c(10,13,15), names_to = "Species", values_to = "Biovolume") # new dplyr version
datastatsMMP1$NP_medium <- factor(datastatsMMP1$NP_medium, levels=c("17.5","35","70")) # give specific order to the factor levels
datastatsMMP1$Treatment <- factor(datastatsMMP1$Treatment, levels=c("Ctrl","P","N","N&P"))
datastatsMMP1$Species <- factor(datastatsMMP1$Species, levels=c("Ana_biovol_phase1","Cry_biovol_phase1","Ste_biovol_phase1"))
levels(datastatsMMP1$Species)<- c("A. variabilis","C. ovata", "S. hantzschii")

dataMMP1<- datastatsMMP1%>%
  group_by(Community, NP_medium, Treatment, Species)%>%
  summarise("MMP"=(Biovolume/Total_Biovol)*100)%>%
  summarise(mean=mean(na.omit(MMP)), 
            quant=quantile(na.omit(MMP),probs = 0.75),
            sd= sd(na.omit(MMP))) #mean and 3rd quantile
# highest value  6.21 +/- 8.94

###PHASE 2 - Sub-dominant species
datastatsMMP2 <- datastats2 %>% 
  pivot_longer(cols = c(10,13,15), names_to = "Species", values_to = "Biovolume") # new dplyr version
datastatsMMP2$NP_medium <- factor(datastatsMMP2$NP_medium, levels=c("17.5","35","70")) # give specific order to the factor levels
datastatsMMP2$Treatment <- factor(datastatsMMP2$Treatment, levels=c("Ctrl","P","N","N&P"))
datastatsMMP2$Species <- factor(datastatsMMP2$Species, levels=c("Ana_biovol_phase2","Cry_biovol_phase2","Ste_biovol_phase2"))
levels(datastatsMMP2$Species)<- c("A. variabilis","C. ovata", "S. hantzschii")

dataMMP2<- datastatsMMP2%>%
  group_by(Community, NP_medium, Treatment, Species)%>%
  summarise("MMP"=(Biovolume/Total_Biovol)*100)%>%
  summarise(mean=mean(na.omit(MMP)), 
            quant=quantile(na.omit(MMP),probs = 0.75),
            sd= sd(na.omit(MMP))) #mean and 3rd quantile
# highest value  2.61 +/- 3.62

###RESULTS - TABLE 2 - BIOVOLUME ~ Medium x Treatment x Community - Phase 1 & Phase 2####
#model :  1 MxTxC - VAL
lmod1 <- lm(log10(Total_Biovol)~(Medium*Treatment*Community),data = datastats1)
anova(lmod1)
summary(lmod1)

#Model validation
autoplot(lmod1, smooth.colour = NA)
hist(lmod1$residuals)

#model :  MxTxC - VAL
lmod2 <- lm(log10(Total_Biovol)~(Medium*Treatment*Community),data = datastats2)
anova(lmod2)
summary(lmod2)

#Model validation
autoplot(lmod2, smooth.colour = NA)
hist(lmod2$residuals) 


###RESULTS - TABLE 3 - BIOVOLUME Phase 2#####
#is total biovolume explained by all species (in that community) biovolume?
#Multiple linear regression: order of explanatory variables based on which 
#one explains more variance in single  (species) regressions.
#Phase 2, Community 1 - N:P = 17.5 VAL####
lmod1N <- lm(log(Total_Biovol)~(log(Syn_biovol_phase2)+log(Nan_biovol_phase2)), 
            data = datastats2[13:24,])
anova(lmod1N)
summary(lmod1N)
#Model validation
autoplot(lmod1N, smooth.colour = NA)

#Multicollinearity of variables. VIF = 1 no correlation; VIF = 1-5 moderate correlation; VIF > 5 correlation 
vif(lmod1N) #no corr

#Backward selection to see if a variables can be dropped from the model (AIC comparison)
drop1(lmod1N, test = "F") #keep both variables, AIC higher

anov <- anova(lmod1N); anov
paste0("R = ", round(summary(lmod1N)$r.square, 2)) # R full model
# Variance contributions
var.contr <- round(anov$`Sum Sq`/sum(anov$`Sum Sq`)*100, 2)
tab.output <- cbind(anov,var.contr); tab.output

#Phase 2, Community 1 - N&P low VAL####
lmod1NP <- lm(log(Total_Biovol)~(log(Syn_biovol_phase2)+log(Nan_biovol_phase2)), 
            data = datastats2[1:12,])
anova(lmod1NP)
summary(lmod1NP)
#Model validation
autoplot(lmod1NP, smooth.colour = NA)

#Multicollinearity of variables. VIF = 1 no correlation; VIF = 1-5 moderate correlation; VIF > 5 correlation 
vif(lmod1NP) # no corr

#Backward selection to see if a variables can be dropped from the model (AIC comparison)
drop1(lmod1NP) #keep both variables, AIC higher

anov <- anova(lmod1NP); anov
paste0("R = ", round(summary(lmod1NP)$r.square, 2)) # R full model
# Variance contributions
var.contr <- round(anov$`Sum Sq`/sum(anov$`Sum Sq`)*100, 2)
tab.output <- cbind(anov,var.contr); tab.output

#Phase 2, Community 1 - P low VAL####
lmod1P <- lm(log(Total_Biovol)~(log(Syn_biovol_phase2)+log(Nan_biovol_phase2)), data = datastats2[25:36,])
anova(lmod1P)
summary(lmod1P)
#Model validation
autoplot(lmod1P, smooth.colour = NA)

#Multicollinearity of variables. VIF = 1 no correlation; VIF = 1-5 moderate correlation; VIF > 5 correlation 
vif(lmod1P) #no corr

#Backward selection to see if a variables can be dropped from the model (AIC comparison)
drop1(lmod1P, test = "F") #AIC higher without Nannochloropsis, best model with Synechococcus only
                          #BUT keep Nannochloropsis so that contributed variance can be shown in the table

anov <- anova(lmod1P); anov
paste0("R = ", round(summary(lmod1P)$r.square, 2)) # R full model
# Variance contributions
var.contr <- round(anov$`Sum Sq`/sum(anov$`Sum Sq`)*100, 2)
tab.output <- cbind(anov,var.contr); tab.output

#Phase 2, Community 2 - N:P = 17.5 VAL####
lmod2N <- lm(log(Total_Biovol)~(log(Acu_biovol_phase2)+log(Mon_biovol_phase2)+log(Syn_biovol_phase2)), data = datastats2[49:60,])
anova(lmod2N)
summary(lmod2N)
#Model validation
autoplot(lmod2N, smooth.colour = NA)

#Multicollinearity of variables. VIF = 1 no correlation; VIF = 1-5 moderate correlation; VIF > 5 correlation 
vif(lmod2N) # green algae Acutodesmus and Monoraphidium correlated --> one (Monoraphidium) can be dropped out

lmod2N <- lm(log(Total_Biovol)~(log(Acu_biovol_phase2)+log(Syn_biovol_phase2)), data = datastats2[49:60,])
anova(lmod2N)
summary(lmod2N)
#Model validation
autoplot(lmod2N, smooth.colour = NA)

#Backward selection to see if a variables can be dropped from the model (AIC comparison)
drop1(lmod2N, test = "F") #keep all variables, AIC higher

anov <- anova(lmod2N); anov
paste0("R = ", round(summary(lmod2N)$r.square, 2)) # R full model
# Variance contributions
var.contr <- round(anov$`Sum Sq`/sum(anov$`Sum Sq`)*100, 2)
tab.output <- cbind(anov,var.contr); tab.output

#Phase 2, Community 2 - N&P low VAL####
lmod2NP <- lm(log(Total_Biovol)~(log(Acu_biovol_phase2)+log(Mon_biovol_phase2)+log(Syn_biovol_phase2)), data = datastats2[37:48,])
anova(lmod2NP)
summary(lmod2NP)
#Model validation
autoplot(lmod2NP, smooth.colour = NA)

#Multicollinearity of variables. VIF = 1 no correlation; VIF = 1-5 moderate correlation; VIF > 5 correlation 
vif(lmod2NP) # green algae Acutodesmus and Monoraphidium correlated --> one (Monoraphidium) can be dropped out

lmod2NP <- lm(log(Total_Biovol)~(log(Acu_biovol_phase2)+log(Syn_biovol_phase2)), data = datastats2[37:48,])
anova(lmod2NP)
summary(lmod2NP)
#Model validation
autoplot(lmod2NP, smooth.colour = NA)

#Backward selection to see if a variables can be dropped from the model (AIC comparison)
drop1(lmod2NP, test = "F") #keep all variables, AIC higher

anov <- anova(lmod2NP); anov
paste0("R = ", round(summary(lmod2NP)$r.square, 2)) # R full model
# Variance contributions
var.contr <- round(anov$`Sum Sq`/sum(anov$`Sum Sq`)*100, 2)
tab.output <- cbind(anov,var.contr); tab.output

#Phase 2, Community 2 - P low VAL####
lmod2P <- lm(log(Total_Biovol)~(log(Acu_biovol_phase2)+log(Mon_biovol_phase2)+log(Syn_biovol_phase2)), data = datastats2[61:71,])
anova(lmod2P)
summary(lmod2P)
#Model validation
autoplot(lmod2P, smooth.colour = NA)

#Multicollinearity of variables. VIF = 1 no correlation; VIF = 1-5 moderate correlation; VIF > 5 correlation 
vif(lmod2P) # green algae Acutodesmus and Monoraphidium correlated --> one (Monoraphidium) can be dropped out

lmod2P <- lm(log(Total_Biovol)~(log(Acu_biovol_phase2)+log(Syn_biovol_phase2)), data = datastats2[61:71,])
anova(lmod2P)
summary(lmod2P)
#Model validation
autoplot(lmod2P, smooth.colour = NA)

#Backward selection to see if a variables can be dropped from the model (AIC comparison)
drop1(lmod2P, test = "F") #keep all variables, AIC higher

anov <- anova(lmod2P); anov
paste0("R = ", round(summary(lmod2P)$r.square, 2)) # R full model
# Variance contributions
var.contr <- round(anov$`Sum Sq`/sum(anov$`Sum Sq`)*100, 2)
tab.output <- cbind(anov,var.contr); tab.output

#Phase 2, Community 3 - N:P = 17.5 VAL####
lmod3N <- lm(log(Total_Biovol)~(log(Acu_biovol_phase2)+log(Mon_biovol_phase2)+log(Syn_biovol_phase2)+log(Nan_biovol_phase2)), data = datastats2[84:95,])
anova(lmod3N)
summary(lmod3N)
#Model validation
autoplot(lmod3N, smooth.colour = NA)

#Multicollinearity of variables. VIF = 1 no correlation; VIF = 1-5 moderate correlation; VIF > 5 correlation 
vif(lmod3N) # green algae Acutodesmus and Monoraphidium very correlated --> one (Monoraphidium) can be dropped out

lmod3N <- lm(log(Total_Biovol)~(log(Acu_biovol_phase2)+log(Syn_biovol_phase2)+log(Nan_biovol_phase2)), data = datastats2[84:95,])
anova(lmod3N)
summary(lmod3N)
#Model validation
autoplot(lmod3N, smooth.colour = NA)

#Backward selection to see if a variables can be dropped from the model (AIC comparison)
drop1(lmod3N, test = "F") #keep all variables, AIC higher BUT

anov <- anova(lmod3N); anov
paste0("R = ", round(summary(lmod3N)$r.square, 2)) # R full model
# Variance contributions
var.contr <- round(anov$`Sum Sq`/sum(anov$`Sum Sq`)*100, 2)
tab.output <- cbind(anov,var.contr); tab.output

#Phase 2, Community 3 - N&P low VAL####
lmod3NP <- lm(log(Total_Biovol)~(log(Acu_biovol_phase2)+log(Mon_biovol_phase2)+log(Syn_biovol_phase2)+log(Nan_biovol_phase2)),
            data = datastats2[72:83,])
anova(lmod3NP)
summary(lmod3NP)
#Model validation
autoplot(lmod3NP, smooth.colour = NA)

#Multicollinearity of variables. VIF = 1 no correlation; VIF = 1-5 moderate correlation; VIF > 5 correlation 
vif(lmod3NP) # green algae Acutodesmus and Monoraphidium correlated --> one (Monoraphidium) can be dropped out

lmod3NP <- lm(log(Total_Biovol)~(log(Acu_biovol_phase2)+log(Syn_biovol_phase2)+log(Nan_biovol_phase2)),
              data = datastats2[72:83,])
anova(lmod3NP)
summary(lmod3NP)
#Model validation
autoplot(lmod3NP, smooth.colour = NA) 

#Backward selection to see if a variables can be dropped from the model (AIC comparison)
drop1(lmod3NP, test = "F") #AIC higher when Nannochloropsis excluded

lmod3NP <- lm(log(Total_Biovol)~(log(Acu_biovol_phase2)+log(Syn_biovol_phase2)),
              data = datastats2[72:83,])
anova(lmod3NP)
summary(lmod3NP)
#Model validation
autoplot(lmod3NP, smooth.colour = NA)

anov <- anova(lmod3NP); anov
paste0("R = ", round(summary(lmod3NP)$r.square, 2)) # R full model
# Variance contributions
var.contr <- round(anov$`Sum Sq`/sum(anov$`Sum Sq`)*100, 2)
tab.output <- cbind(anov,var.contr); tab.output

#Phase 2, Community 3 - P low VAL####
lmod3P <- lm(log(Total_Biovol)~(log(Syn_biovol_phase2)+log(Mon_biovol_phase2)+log(Acu_biovol_phase2)+log(Nan_biovol_phase2)), data = datastats2[96:107,])
anova(lmod3P)
summary(lmod3P)
#Model validation
autoplot(lmod3P, smooth.colour = NA)

#Multicollinearity of variables. VIF = 1 no correlation; VIF = 1-5 moderate correlation; VIF > 5 correlation 
vif(lmod3P) # Syn and Monoraphidium correlated --> one (Monoraphidium) can be dropped out

lmod3P <- lm(log(Total_Biovol)~(log(Syn_biovol_phase2)+log(Acu_biovol_phase2)+log(Nan_biovol_phase2)), data = datastats2[96:107,])
anova(lmod3P)
summary(lmod3P)
#Model validation
autoplot(lmod3P, smooth.colour = NA) #looks okish

#Backward selection to see if a variables can be dropped from the model (AIC comparison)
drop1(lmod3P, test = "F") #AIC higher when Nannchloropsis excluded

lmod3P <- lm(log(Total_Biovol)~(log(Syn_biovol_phase2)+log(Acu_biovol_phase2)), data = datastats2[96:107,])
anova(lmod3P)
summary(lmod3P)
#Model validation
autoplot(lmod3P, smooth.colour = NA)

anov <- anova(lmod3P); anov
paste0("R = ", round(summary(lmod3P)$r.square, 3)) # R full model
# Variance contributions
var.contr <- round(anov$`Sum Sq`/sum(anov$`Sum Sq`)*100, 2)
tab.output <- cbind(anov,var.contr); tab.output


###RESULTS - TABLE S1 - BIOVOLUME Phase 2####
#Phase 2, Community 1 - Syne - N:P = 17.5 VAL####
lmodSyn1 <- lm(log(Total_Biovol)~log(Syn_biovol_phase2), data = datastats2[13:24,])
anova(lmodSyn1)
summary(lmodSyn1)
#Model validation
autoplot(lmodSyn1, smooth.colour = NA)

#Phase 2, Community 1 - Syne - N:P = 35 VAL####
lmodSyn1 <- lm(log(Total_Biovol)~log(Syn_biovol_phase2), data = datastats2[1:12,])
anova(lmodSyn1)
summary(lmodSyn1)
#Model validation
autoplot(lmodSyn1, smooth.colour = NA)

#Phase 2, Community 1 - Syne - N:P = 70 VAL####
lmodSyn1 <- lm(log(Total_Biovol)~log(Syn_biovol_phase2), data = datastats2[25:36,])
anova(lmodSyn1)
summary(lmodSyn1)
#Model validation
autoplot(lmodSyn1, smooth.colour = NA)

#Phase 2, Community 1 - Nan - N:P = 17.5 VAL####
lmodNan1 <- lm(log(Total_Biovol)~log(Nan_biovol_phase2), data = datastats2[13:24,])
anova(lmodNan1)
summary(lmodNan1)
#Model validation
autoplot(lmodNan1, smooth.colour = NA)

#Phase 2, Community 1 - Nan - N:P = 35 VAL####
lmodNan1 <- lm(log(Total_Biovol)~log(Nan_biovol_phase2), data = datastats2[1:12,])
anova(lmodNan1)
summary(lmodNan1)
#Model validation
autoplot(lmodNan1, smooth.colour = NA)

#Phase 2, Community 1 - Nan - N:P = 70 VAL####
lmodNan1 <- lm(log(Total_Biovol)~log(Nan_biovol_phase2), data = datastats2[25:36,])
anova(lmodNan1)
summary(lmodNan1)
#Model validation
autoplot(lmodSyn1, smooth.colour = NA)

#Phase 2, Community 2 - Syne - N:P = 17.5 VAL####
lmodSyn1 <- lm(log(Total_Biovol)~log(Syn_biovol_phase2), data = datastats2[49:60,])
anova(lmodSyn1)
summary(lmodSyn1)
#Model validation
autoplot(lmodSyn1, smooth.colour = NA)

#Phase 2, Community 2 - Syne - N:P = 35 VAL####
lmodSyn1 <- lm(log(Total_Biovol)~log(Syn_biovol_phase2), data = datastats2[37:48,])
anova(lmodSyn1)
summary(lmodSyn1)
#Model validation
autoplot(lmodSyn1, smooth.colour = NA)

#Phase 2, Community 2 - Syne - N:P = 70 VAL####
lmodSyn1 <- lm(log(Total_Biovol)~log(Syn_biovol_phase2), data = datastats2[61:71,])
anova(lmodSyn1)
summary(lmodSyn1)
#Model validation
autoplot(lmodSyn1, smooth.colour = NA)

#Phase 2, Community 2 - Mon - N:P = 17.5 VAL####
lmodMon1 <- lm(log(Total_Biovol)~log(Mon_biovol_phase2), data = datastats2[49:60,])
anova(lmodMon1)
summary(lmodMon1)
#Model validation
autoplot(lmodMon1, smooth.colour = NA)

#Phase 2, Community 2 - Mon - N:P = 35 VAL####
lmodMon1 <- lm(log(Total_Biovol)~log(Mon_biovol_phase2), data = datastats2[37:48,])
anova(lmodMon1)
summary(lmodMon1)
#Model validation
autoplot(lmodMon1, smooth.colour = NA)

#Phase 2, Community 2 - Mon - N:P = 70 VAL####
lmodMon1 <- lm(log(Total_Biovol)~log(Mon_biovol_phase2), data = datastats2[61:71,])
anova(lmodMon1)
summary(lmodMon1)
#Model validation
autoplot(lmodMon1, smooth.colour = NA)

#Phase 2, Community 2 - Acu - N:P = 17.5 VAL####
lmodAcu1 <- lm(log(Total_Biovol)~log(Acu_biovol_phase2), data = datastats2[49:60,])
anova(lmodAcu1)
summary(lmodAcu1)
#Model validation
autoplot(lmodAcu1, smooth.colour = NA)

#Phase 2, Community 2 - Acu - N:P = 35 VAL####
lmodAcu1 <- lm(log(Total_Biovol)~log(Acu_biovol_phase2), data = datastats2[37:48,])
anova(lmodAcu1)
summary(lmodAcu1)
#Model validation
autoplot(lmodAcu1, smooth.colour = NA)

#Phase 2, Community 2 - Acu - N:P = 70 VAL####
lmodAcu1 <- lm(log(Total_Biovol)~log(Acu_biovol_phase2), data = datastats2[61:71,])
anova(lmodAcu1)
summary(lmodAcu1)
#Model validation
autoplot(lmodAcu1, smooth.colour = NA)

#Phase 2, Community 3 - Syne - N:P = 17.5 VAL####
lmodSyn1 <- lm(log(Total_Biovol)~log(Syn_biovol_phase2), data = datastats2[84:95,])
anova(lmodSyn1)
summary(lmodSyn1)
#Model validation
autoplot(lmodSyn1, smooth.colour = NA)

#Phase 2, Community 3 - Syne - N:P = 35 VAL####
lmodSyn1 <- lm(log(Total_Biovol)~log(Syn_biovol_phase2), data = datastats2[72:83,])
anova(lmodSyn1)
summary(lmodSyn1)
#Model validation
autoplot(lmodSyn1, smooth.colour = NA)

#Phase 2, Community 3 - Syne - N:P = 70 VAL####
lmodSyn1 <- lm(log(Total_Biovol)~log(Syn_biovol_phase2), data = datastats2[96:107,])
anova(lmodSyn1)
summary(lmodSyn1)
#Model validation
autoplot(lmodSyn1, smooth.colour = NA)

#Phase 2, Community 3 - Nan - N:P = 17.5 VAL####
lmodNan1 <- lm(log(Total_Biovol)~log(Nan_biovol_phase2), data = datastats2[84:95,])
anova(lmodNan1)
summary(lmodNan1)
#Model validation
autoplot(lmodNan1, smooth.colour = NA)

#Phase 2, Community 3 - Nan - N:P = 35 VAL####
lmodNan1 <- lm(log(Total_Biovol)~log(Nan_biovol_phase2), data = datastats2[72:83,])
anova(lmodNan1)
summary(lmodNan1)
#Model validation
autoplot(lmodNan1, smooth.colour = NA)

#Phase 2, Community 3 - Nan - N:P = 70 VAL####
lmodNan1 <- lm(log(Total_Biovol)~log(Nan_biovol_phase2), data = datastats2[96:107,])
anova(lmodNan1)
summary(lmodNan1)
#Model validation
autoplot(lmodSyn1, smooth.colour = NA)

#Phase 2, Community 3 - Mon - N:P = 17.5 VAL####
lmodMon1 <- lm(log(Total_Biovol)~log(Mon_biovol_phase2), data = datastats2[84:95,])
anova(lmodMon1)
summary(lmodMon1)
#Model validation
autoplot(lmodMon1, smooth.colour = NA)

#Phase 2, Community 3 - Mon - N:P = 35 VAL####
lmodMon1 <- lm(log(Total_Biovol)~log(Mon_biovol_phase2), data = datastats2[72:83,])
anova(lmodMon1)
summary(lmodMon1)
#Model validation
autoplot(lmodMon1, smooth.colour = NA)

#Phase 2, Community 3 - Mon - N:P = 70 VAL####
lmodMon1 <- lm(log(Total_Biovol)~log(Mon_biovol_phase2), data = datastats2[96:107,])
anova(lmodMon1)
summary(lmodMon1)
#Model validation
autoplot(lmodMon1, smooth.colour = NA)

#Phase 2, Community 3 - Acu - N:P = 17.5 VAL####
lmodAcu1 <- lm(log(Total_Biovol)~log(Acu_biovol_phase2), data = datastats2[84:95,])
anova(lmodAcu1)
summary(lmodAcu1)
#Model validation
autoplot(lmodAcu1, smooth.colour = NA)

#Phase 2, Community 3 - Acu - N:P = 35 VAL####
lmodAcu1 <- lm(log(Total_Biovol)~log(Acu_biovol_phase2), data = datastats2[72:83,])
anova(lmodAcu1)
summary(lmodAcu1)
#Model validation
autoplot(lmodAcu1, smooth.colour = NA)

#Phase 2, Community 3 - Acu - N:P = 70 VAL####
lmodAcu1 <- lm(log(Total_Biovol)~log(Acu_biovol_phase2), data = datastats2[96:107,])
anova(lmodAcu1)
summary(lmodAcu1)
#Model validation
autoplot(lmodAcu1, smooth.colour = NA)