## Script for Data Visualization
rm(list=ls())

setwd("") #insert directory of csv file
getwd()

#Packages needed 
library(tidyverse) 
library(ggpubr)
library(dplyr)
library(ggh4x) #needed for color-coded community facets
library(gtable) #empty facets
library(agricolae) #for Tukey's Post-hoc tests

# function needed for stat_summary function in ggplot
mean_sd = function(x)
  return( data.frame( y = c(mean(x)), ymin = c(mean(x)-sd(x)), ymax = c(mean(x)+sd(x))))

#Read in data####
datall <- read_csv("", skip = 1,show_col_types = FALSE) #insert csv data file
dim(datall)  

color.scheme <- c("grey","red","blue","purple")
color.scheme.2 <- c("cyan","springgreen","darkorange")
stripFACET <- strip_themed(background_y = elem_list_rect(fill = color.scheme.2 )) #ggh4x for ffacets
stripGRIDBiom <- strip_themed(background_y = elem_list_rect(fill = color.scheme.2 ),
                           background_x = elem_list_rect(fill = "gray"),
                          by_layer_x = FALSE) #ggh4x for facets
stripGRIDBiov <- strip_themed(background_x = elem_list_rect(fill = color.scheme.2 ),
                              background_y = elem_list_rect(fill = "gray"),
                              by_layer_x = FALSE) #ggh4x for facets
stripGRIDBrel <- strip_themed(background_x = elem_list_rect(fill = "lightgray" ),
                              background_y = elem_list_rect(fill = color.scheme),
                              by_layer_y = FALSE,
                              text_x = elem_list_text(size = 8)) #ggh4x for facets
text.on.each.panel <- "Community"
COMMnames <- c("Community 1", "Community 2", "Community 3")

###FIGURE 2 - OD throughout the experiment ######
dataOD <-(datall[,-c(6:16,39:81)])
dataOD.long <- dataOD %>% 
  pivot_longer(cols = 6:27,names_to = "day", values_to = "OD")
dataOD.long$day <- as.integer(dataOD.long$day) 
dataOD.long <- dataOD.long %>% mutate(day = as.integer(day)) 
dataOD.long$NP_medium <- factor(dataOD.long$NP_medium, levels=c("17.5","35","70")) # give specific order to the factor levels
dataOD.long$Treatment <- factor(dataOD.long$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(dataOD.long$NP_medium)<- c("Medium N:P = 17.5","Medium N:P = 35","Medium N:P = 70")

dataOD.means <- dataOD.long %>% group_by(Community, Medium, NP_medium, Treatment,day) %>% 
  summarise(OD.mean = mean(OD, na.rm = T))
dataOD.means <- as.data.frame(dataOD.means)

color.scheme <- c("darkgrey","red","blue","purple")
shape.scheme <- c(23,25,24,21)

filter(dataOD.long) %>%
  ggplot(dataOD.long, mapping= aes(x=day, y=OD, color=Treatment, shape = Treatment, fill = Treatment)) + 
  theme_bw() + 
  geom_smooth(data = filter(dataOD.means,Community==1), mapping=aes(x=day,y=OD.mean, color=Treatment),linewidth=0.6, se = FALSE) +
  geom_point(data = filter(dataOD.long,Community==1),cex = 0.5) +
  geom_smooth(data = filter(dataOD.means,Community==2), mapping=aes(x=day,y=OD.mean, color=Treatment),linewidth=0.6, se = FALSE) +
  geom_point(data = filter(dataOD.long,Community==2),cex = 0.5)+
  geom_smooth(data = filter(dataOD.means,Community==3), mapping=aes(x=day,y=OD.mean, color=Treatment),linewidth=0.6, se = FALSE) +
  geom_point(data = filter(dataOD.long,Community==3),cex = 0.5)+
  scale_color_manual(values = color.scheme)+
  scale_shape_manual(values = shape.scheme)+
  scale_fill_manual(values= color.scheme)+
  scale_y_continuous(breaks=c(0,0.05,0.1,0.15,0.2,0.25)) +
  labs(y = "Phytoplankton biomass (OD)", x = "Day of experiment") +
  geom_vline(xintercept = 21, linetype="dashed", size=0.5) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        strip.text.y = element_text(angle = 0),
        strip.text.y.right = element_text(angle = 270)) +
  facet_grid2(Community~NP_medium, labeller = label_bquote(rows=.(text.on.each.panel)~.(Community)),
              strip = stripGRIDBiom)#

###FIGURE Supporting 2 - Biovolume Phase 1 - ALL SPECIES (no Tuk. letters) #####
datbv1 <- (datall[,-c(6:53,61:81)])

datbv1$Total_Biovol <- rowSums( datbv1[,6:12] )

datbvsp1 <- datbv1 %>% 
  relocate(Total_Biovol, .after=Treatment)%>% 
  pivot_longer(cols = 6:13, names_to = "Species", values_to = "Biovolume") # new dplyr version
datbvsp1$NP_medium <- factor(datbvsp1$NP_medium, levels=c("17.5","35","70")) # give specific order to the factor levels
datbvsp1$Treatment <- factor(datbvsp1$Treatment, levels=c("Ctrl","P","N","N&P"))
datbvsp1$Species <- factor(datbvsp1$Species, levels=c("Total_Biovol","Syn_biovol_phase1","Ana_biovol_phase1", "Acu_biovol_phase1",
                                                "Mon_biovol_phase1","Cry_biovol_phase1","Nan_biovol_phase1",
                                                "Ste_biovol_phase1"))
levels(datbvsp1$Species)<- c("Total Biovolume","S. elongatus","A. variabilis","A. obliquus","M. minutum", "C. ovata","N. limnetica",
                                      "S. hantzschii")

FIGS1 <- ggplot(datbvsp1,aes(x=NP_medium, y=Biovolume, fill=Treatment)) +  
  theme_bw() + # this 'theme' makes the plot looking nicer
  stat_summary(geom = "bar", fun.data=mean_sd, position = "dodge", color="darkgrey", size = 0.1) +
  stat_summary(geom = "errorbar", fun.data=mean_sd, position = "dodge", size = 0.3, na.rm=FALSE) +
  scale_fill_manual(values = color.scheme) +
  geom_vline(xintercept = c(1.5,2.5), color="darkgrey")+
  theme(panel.grid.major.x = element_blank(), panel.grid.minor.x = element_blank(), 
        panel.grid.minor.y = element_blank(),
        axis.text.x = element_text(size = 7),
        strip.text.y = element_text(angle = 0, size = 7))+
  facet_grid2(Species~Community, labeller = label_bquote(cols=.(text.on.each.panel)~.(Community)),
              strip = stripGRIDBiov,scales = "free_y")+
  labs(x = "Medium N:P")+
  ylab(expression(Biovolume~(mm^3~mL^-1)))

FIGS1 %>%# 6 x 6.5
  # Generate gtable of ggplot object
  ggplot2::ggplot_build() %>% ggplot2::ggplot_gtable() %>%
  gtable_filter(pattern = "panel-2-2$", invert = TRUE)%>% #acu 1
  gtable_filter(pattern = "panel-5-2$", invert = TRUE)%>% #mono 1
  gtable_filter(pattern = "panel-1-3$", invert = TRUE)%>%  #cry 2
  gtable_filter(pattern = "panel-4-3$", invert = TRUE)%>%  #nanno 2
  gtable_filter(pattern = "panel-7-3$", invert = TRUE)%>%  #steph 2
# Plot the modified gtable
  {grid::grid.newpage(); grid::grid.draw(.)}

###FIGURE Supporting 3 - Biovolume Phase 2 - ALL SPECIES (sample 40 excluded, no Tuk. letters)#####
datbv2 <- (datall[-70,-c(6:74)]) #exclude sample 40, outlier
datbv2$Total_Biovol <- rowSums( datbv2[,6:12] )

datbvsp2 <- datbv2 %>% 
  relocate(Total_Biovol, .after=Treatment)%>% 
  pivot_longer(cols = 6:13, names_to = "Species", values_to = "Biovolume") # new dplyr version
datbvsp2$NP_medium <- factor(datbvsp2$NP_medium, levels=c("17.5","35","70")) # give specific order to the factor levels
datbvsp2$Treatment <- factor(datbvsp2$Treatment, levels=c("Ctrl","P","N","N&P"))
datbvsp2$Species <- factor(datbvsp2$Species, levels=c("Total_Biovol", "Syn_biovol_phase2","Ana_biovol_phase2", "Acu_biovol_phase2",
                                                "Mon_biovol_phase2","Cry_biovol_phase2","Nan_biovol_phase2",
                                                "Ste_biovol_phase2"))
levels(datbvsp2$Species)<- c("Total Biovolume","S. elongatus","A. variabilis","A. obliquus", "M. minutum", "C. ovata","N. limnetica",
                          "S. hantzschii")

FIGS2<- ggplot(datbvsp2,aes(x=NP_medium, y=Biovolume, fill=Treatment)) +  
  theme_bw() + # this 'theme' makes the plot looking nicer
  stat_summary(geom = "bar", fun.data=mean_sd, position = "dodge", color="darkgrey", size = 0.1) +
  stat_summary(geom = "errorbar", fun.data=mean_sd, position = "dodge", size = 0.3) +
  scale_fill_manual(values = color.scheme) +
  geom_vline(xintercept = c(1.5,2.5), color="darkgrey")+
  theme(panel.grid.major.x = element_blank(), panel.grid.minor.x = element_blank(), 
        panel.grid.minor.y = element_blank(),
        axis.text.x = element_text(size = 7),
        strip.text.y = element_text(angle = 0, size = 7))+
  facet_grid2(Species~Community, labeller = label_bquote(cols=.(text.on.each.panel)~.(Community)),
              strip = stripGRIDBiov,scales = "free_y")+
  labs(x= "Medium N:P")+
  ylab(expression(Biovolume~(mm^3~mL^-1)))


FIGS2 %>%# 6 x 6.5
  # Generate gtable of ggplot object
  ggplot2::ggplot_build() %>% ggplot2::ggplot_gtable() %>%
  gtable_filter(pattern = "panel-2-2$", invert = TRUE)%>% #acu 1
  gtable_filter(pattern = "panel-5-2$", invert = TRUE)%>% #mono 1
  gtable_filter(pattern = "panel-1-3$", invert = TRUE)%>%  #cry 2
  gtable_filter(pattern = "panel-4-3$", invert = TRUE)%>%  #nanno 2
  gtable_filter(pattern = "panel-7-3$", invert = TRUE)%>%  #steph 2
  # Plot the modified gtable
  {grid::grid.newpage(); grid::grid.draw(.)}

###FIGURE 3 - Biovolume Phase 2 - Key Species (sample 40 excluded, with Tuk. letters) #####
datbvv2 <- (datall[- 70,-c(6:74, 76, 79,81)])
datbvv2$Total_Biovol <- rowSums( datbvv2[,6:9] )

datbvvsp2 <- datbvv2 %>% 
  relocate(Total_Biovol, .after=Treatment)%>% 
  pivot_longer(cols = 6:10,names_to = "Species", values_to = "Biovolume") # new dplyr version
datbvvsp2$NP_medium <- factor(datbvvsp2$NP_medium, levels=c("17.5","35","70")) # give specific order to the factor levels
datbvvsp2$Treatment <- factor(datbvvsp2$Treatment, levels=c("Ctrl","P","N","N&P"))
datbvvsp2$Species <- factor(datbvvsp2$Species, levels=c("Total_Biovol","Syn_biovol_phase2","Acu_biovol_phase2",
                                                      "Mon_biovol_phase2","Nan_biovol_phase2"))
levels(datbvvsp2$Species)<- c("Total Biovolume", "S. elongatus","A. obliquus","M. minutum","N. limnetica")

lab1_TB_N <- data.frame(label =  c("a","ab","b","b"), Community ="1", NP_Medium = "17.5",
                        Species = "Total Biovolume", x= c(0.7,0.9,1.1,1.3), y =0.19)
lab1_TB_NP <- data.frame(label =  c("a","a","a","b"), Community ="1",NP_Medium = "35",
                         Species = "Total Biovolume", x= c(1.7,1.9,2.1,2.3), y =0.19)
lab1_TB_P <- data.frame(label =  c("a","a","a","b"), Community ="1",NP_Medium = "70",
                        Species = "Total Biovolume", x= c(2.7,2.9,3.1,3.3), y =0.19)
lab2_TB_N <- data.frame(label =  c("a","a","b","b"), Community ="2", NP_Medium = "17.5",
                        Species = "Total Biovolume", x= c(0.7,0.9,1.1,1.3), y =0.55)
lab2_TB_NP <- data.frame(label =  c("a","a","b","b"), Community ="2",NP_Medium = "35",
                         Species = "Total Biovolume", x= c(1.7,1.9,2.1,2.3), y =0.66)
lab2_TB_P <- data.frame(label =  c("a","ab","b","b"), Community ="2",NP_Medium = "70",
                        Species = "Total Biovolume", x= c(2.7,2.9,3.1,3.3), y =0.65)
lab3_TB_N <- data.frame(label =  c("a","a","b","b"), Community ="3",NP_Medium = "17.5",
                        Species = "Total Biovolume", x= c(0.7,0.9,1.1,1.3), y =0.35)
lab3_TB_NP <- data.frame(label =  c("a","a","b","b"), Community ="3",NP_Medium = "35",
                         Species = "Total Biovolume", x= c(1.7,1.9,2.1,2.3), y =0.33)
lab3_TB_P <- data.frame(label =  c("a","a","a","a"), Community ="3",NP_Medium = "70",
                        Species = "Total Biovolume", x= c(2.7,2.9,3.1,3.3), y =0.34)
lab1_Syn_N <- data.frame(label =  c("a","ab","b","b"), Community ="1",NP_Medium = "17.5",
                         Species = "S. elongatus", x= c(0.7,0.9,1.1,1.3), y =0.15)
lab1_Syn_NP <- data.frame(label =  c("a","a","a","b"), Community ="1",NP_Medium = "35",
                          Species = "S. elongatus", x= c(1.7,1.9,2.1,2.3), y =0.15)
lab1_Syn_P <- data.frame(label =  c("a","a","a","b"), Community ="1",NP_Medium = "70",
                         Species = "S. elongatus", x= c(2.7,2.9,3.1,3.3), y =0.14)
lab2_Syn_N <- data.frame(label =  c("a","a","a","a"), Community ="2",NP_Medium = "17.5",
                         Species = "S. elongatus", x= c(0.7,0.9,1.1,1.3), y =0.06)
lab2_Syn_NP <- data.frame(label =  c("a","a","a","a"), Community ="2",NP_Medium = "35",
                          Species = "S. elongatus", x= c(1.7,1.9,2.1,2.3), y =0.06)
lab2_Syn_P <- data.frame(label =  c("a","b","a","ab"), Community ="2",NP_Medium = "70",
                         Species = "S. elongatus", x= c(2.7,2.9,3.1,3.3), y =0.07)
lab3_Syn_N <- data.frame(label =  c("a","a","a","a"), Community ="3",NP_Medium = "17.5",
                         Species = "S. elongatus", x= c(0.7,0.9,1.1,1.3), y =0.08)
lab3_Syn_NP <- data.frame(label =  c("a","a","a","a"), Community ="3",NP_Medium = "35",
                          Species = "S. elongatus", x= c(1.7,1.9,2.1,2.3), y =0.07)
lab3_Syn_P <- data.frame(label =  c("a","a","a","a"), Community ="3",NP_Medium = "70",
                         Species = "S. elongatus", x= c(2.7,2.9,3.1,3.3), y =0.09)
lab2_Acu_N <- data.frame(label =  c("a","a","b","b"), Community ="2",NP_Medium = "17.5",
                         Species = "A. obliquus", x= c(0.7,0.9,1.1,1.3), y =0.43)
lab2_Acu_NP <- data.frame(label =  c("a","a","b","b"), Community ="2",NP_Medium = "35",
                          Species = "A. obliquus", x= c(1.7,1.9,2.1,2.3), y =0.61)
lab2_Acu_P <- data.frame(label =  c("a","a","ab","ab"), Community ="2",NP_Medium = "70",
                         Species = "A. obliquus", x= c(2.7,2.9,3.1,3.3), y =0.60)
lab3_Acu_N <- data.frame(label =  c("a","a","b","b"), Community ="3",NP_Medium = "17.5",
                         Species = "A. obliquus", x= c(0.7,0.9,1.1,1.3), y =0.18)
lab3_Acu_NP <- data.frame(label =  c("a","ab","b","b"), Community ="3",NP_Medium = "35",
                          Species = "A. obliquus", x= c(1.7,1.9,2.1,2.3), y =0.17)
lab3_Acu_P <- data.frame(label =  c("a","a","a","a"), Community ="3",NP_Medium = "70",
                         Species = "A. obliquus", x= c(2.7,2.9,3.1,3.3), y =0.17)
lab2_Mon_N <- data.frame(label =  c("a","a","a","a"), Community ="2",NP_Medium = "17.5",
                         Species = "M. minutum", x= c(0.7,0.9,1.1,1.3), y =0.06)
lab2_Mon_NP <- data.frame(label =  c("a","a","b","ab"), Community ="2",NP_Medium = "35",
                          Species = "M. minutum", x= c(1.7,1.9,2.1,2.3), y =0.05)
lab2_Mon_P <- data.frame(label =  c("a","a","b","b"), Community ="2",NP_Medium = "70",
                         Species = "M. minutum", x= c(2.7,2.9,3.1,3.3), y =0.1)
lab3_Mon_N <- data.frame(label =  c("a","a","b","b"), Community ="3",NP_medium ="17.5",
                         Species = "M. minutum", x= c(0.7,0.9,1.1,1.3), y =0.1)
lab3_Mon_NP <- data.frame(label =  c("a","a","a","a"), Community ="3",NP_Medium = "35",
                          Species = "M. minutum", x= c(1.7,1.9,2.1,2.3), y =0.1)
lab3_Mon_P <- data.frame(label =  c("a","a","a","a"), Community ="3",NP_Medium = "70",
                         Species = "M. minutum", x= c(2.7,2.9,3.1,3.3), y =0.11)
lab1_Nan_N <- data.frame(label =  c("a","a","a","a"), Community ="1",NP_medium ="17.5",
                         Species = "N. limnetica", x= c(0.7,0.9,1.1,1.3), y =0.016)
lab1_Nan_NP <- data.frame(label =  c("a","a","a","a"), Community ="1",NP_Medium = "35",
                          Species = "N. limnetica", x= c(1.7,1.9,2.1,2.3), y =0.01)
lab1_Nan_P <- data.frame(label =  c("a","a","a","a"), Community ="1",NP_Medium = "70",
                         Species = "N. limnetica", x= c(2.7,2.9,3.1,3.3), y =0.006)
lab3_Nan_N <- data.frame(label =  c("a","a","a","a"), Community ="3",NP_medium ="17.5",
                         Species = "N. limnetica", x= c(0.7,0.9,1.1,1.3), y =0.006)
lab3_Nan_NP <- data.frame(label =  c("a","a","a","a"), Community ="3",NP_Medium = "35",
                          Species = "N. limnetica", x= c(1.7,1.9,2.1,2.3), y =0.006)
lab3_Nan_P <- data.frame(label =  c("a","a","a","a"), Community ="3",NP_Medium = "70",
                         Species = "N. limnetica", x= c(2.7,2.9,3.1,3.3), y =0.006)

FIG2 <- ggplot(datbvvsp2,aes(x=NP_medium, y=Biovolume, fill=Treatment)) + 
  theme_bw() + # this 'theme' makes the plot looking nicer
  stat_summary(geom = "bar", fun.data=mean_sd, position = "dodge", color="darkgrey", size = 0.1) +
  stat_summary(geom = "errorbar", fun.data=mean_sd, position = "dodge", size = 0.3) +
  scale_fill_manual(values = color.scheme) +
  geom_vline(xintercept = c(1.5,2.5), color="darkgrey") +
  theme(panel.grid.major.x = element_blank(), panel.grid.minor.x = element_blank(), 
        panel.grid.minor.y = element_blank(),
        axis.text.x = element_text(size = 7),
        strip.text.y = element_text(angle = 0, size = 7))+
  facet_grid2(factor(Species)~Community, labeller = label_bquote(cols=.(text.on.each.panel)~.(Community)),
              strip = stripGRIDBiov,scales = "free_y")+
  labs(x = "Medium N:P")+
  ylab(expression(Biovolume~(mm^3~mL^-1)))+
  geom_text(data = lab1_TB_N, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab1_TB_NP, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab1_TB_P, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab2_TB_N, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab2_TB_NP, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab2_TB_P, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab3_TB_N, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab3_TB_NP, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab3_TB_P, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab1_Syn_N, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab1_Syn_NP, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab1_Syn_P, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab2_Syn_N, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab2_Syn_NP, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab2_Syn_P, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab3_Syn_N, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab3_Syn_NP, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab3_Syn_P, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab2_Acu_N, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab2_Acu_NP, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab2_Acu_P, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab3_Acu_N, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab3_Acu_NP, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab3_Acu_P, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab2_Mon_N, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab2_Mon_NP, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab2_Mon_P, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab3_Mon_N, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab3_Mon_NP, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab3_Mon_P, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab1_Nan_N, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab1_Nan_NP, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab1_Nan_P, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab3_Nan_N, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab3_Nan_NP, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)+
  geom_text(data = lab3_Nan_P, mapping = aes(x=x, y=y, label=label), size = 2,inherit.aes = FALSE)

FIG2 %>% # 6x5
  # Generate gtable of ggplot object
  ggplot2::ggplot_build() %>% ggplot2::ggplot_gtable() %>%
  gtable_filter(pattern = "panel-2-2$", invert = TRUE)%>% #acu 1
  gtable_filter(pattern = "panel-5-2$", invert = TRUE)%>% #mono 1
  gtable_filter(pattern = "panel-4-3$", invert = TRUE)%>%  #nan 2
  # Plot the modified gtable
  {grid::grid.newpage(); grid::grid.draw(.)}


###FIGURE Supporting 4 - Absolute Biovolume Phase 1-2 Differences - ALL SPECIES (sample 40 excluded)####
datbvdiff <- (datall[-70,-c(6:53,61:74)])
datbvdiff$Total_Biovol1 <- rowSums(datbvdiff[,c("Syn_biovol_phase1","Ana_biovol_phase1", "Acu_biovol_phase1",
                                                "Mon_biovol_phase1","Cry_biovol_phase1","Nan_biovol_phase1",
                                                "Ste_biovol_phase1" )], na.rm=TRUE)
datbvdiff$Total_Biovol2 <- rowSums(datbvdiff[,c("Syn_biovol_phase2","Ana_biovol_phase2", "Acu_biovol_phase2",
                                                "Mon_biovol_phase2","Cry_biovol_phase2","Nan_biovol_phase2",
                                                "Ste_biovol_phase2")], na.rm=TRUE)

datbvdiff$Tot_diff <- (datbvdiff$Total_Biovol2 - datbvdiff$Total_Biovol1)
datbvdiff$Syn_diff <- (datbvdiff$Syn_biovol_phase2 - datbvdiff$Syn_biovol_phase1)
datbvdiff$Ana_diff <- (datbvdiff$Ana_biovol_phase2 - datbvdiff$Ana_biovol_phase1)
datbvdiff$Acu_diff <- (datbvdiff$Acu_biovol_phase2 - datbvdiff$Acu_biovol_phase1)
datbvdiff$Mon_diff <- (datbvdiff$Mon_biovol_phase2 - datbvdiff$Mon_biovol_phase1)
datbvdiff$Cry_diff <- (datbvdiff$Cry_biovol_phase2 - datbvdiff$Cry_biovol_phase1)
datbvdiff$Nan_diff <- (datbvdiff$Nan_biovol_phase2 - datbvdiff$Nan_biovol_phase1)
datbvdiff$Ste_diff <- (datbvdiff$Ste_biovol_phase2 - datbvdiff$Ste_biovol_phase1)

datbvdifflong <- datbvdiff[,-c(6:21)] %>% pivot_longer(cols = 6:13, names_to = "Species", values_to = "Biovolume") # new dplyr version
datbvdifflong$NP_medium <- factor(datbvdifflong$NP_medium, levels=c("17.5","35","70")) # give specific order to the factor levels
datbvdifflong$Treatment <- factor(datbvdifflong$Treatment, levels=c("Ctrl","P","N","N&P"))
datbvdifflong$Species <- factor(datbvdifflong$Species, levels=c("Tot_diff","Syn_diff","Ana_diff", "Acu_diff",
                                                                "Mon_diff","Cry_diff","Nan_diff",
                                                                "Ste_diff"))
levels(datbvdifflong$Species)<- c("Total biovolume","S. elongatus","A. variabilis","A. obliquus",
                                  "M. minutum", "C. ovata","N. limnetica",
                                  "S. hantzschii" )

FIGS3<-ggplot(datbvdifflong,aes(x=NP_medium, y=Biovolume, fill=Treatment)) +  # 6 x 6.5
  theme_bw() + # this 'theme' makes the plot looking nicer
  stat_summary(geom = "bar", fun.data=mean_sd, position = "dodge", color="darkgrey", size = 0.1) +
  stat_summary(geom = "errorbar", fun.data=mean_sd, position = "dodge", size = 0.3) +
  scale_fill_manual(values = color.scheme) +
  geom_vline(xintercept = c(1.5,2.5), color="darkgrey") + #geom_hline(yintercept = 0) +
  theme(panel.grid.major.x = element_blank(), panel.grid.minor.x = element_blank(), 
        panel.grid.minor.y = element_blank(),
        axis.text.x = element_text(size = 7),
        strip.text.y = element_text(angle = 0, size = 7))+
  facet_grid2(Species~Community, labeller = label_bquote(cols=.(text.on.each.panel)~.(Community)),
              strip = stripGRIDBiov,scales = "free_y")+
  ylab(expression(Biovolume~(mm^3~mL^-1)~change~from~phase~1~to~phase~2))+
  labs(x = "Medium N:P")

FIGS3 %>%# 6 x 6.5
  # Generate gtable of ggplot object
  ggplot2::ggplot_build() %>% ggplot2::ggplot_gtable() %>%
  gtable_filter(pattern = "panel-2-2$", invert = TRUE)%>% #acu 1
  gtable_filter(pattern = "panel-5-2$", invert = TRUE)%>% #mono 1
  gtable_filter(pattern = "panel-1-3$", invert = TRUE)%>%  #cry 2
  gtable_filter(pattern = "panel-4-3$", invert = TRUE)%>%  #nanno 2
  gtable_filter(pattern = "panel-7-3$", invert = TRUE)%>%  #steph 2
  # Plot the modified gtable
  {grid::grid.newpage(); grid::grid.draw(.)}


###FIGURE 4 - Relative Biovolume Phase 1-2 Differences - ALL SPECIES (sample 40 excluded) #####
datbvrel <- (datall[,-c(6:53,61:74)])
datbvrel[70,6:19]<- NA #replace sample 40 with NAs

#group species in the 3 major groups divided by phase 1 and 2
datbvrel$Total_Biovol1 <- rowSums(datbvrel[,c("Syn_biovol_phase1","Ana_biovol_phase1", "Acu_biovol_phase1",
                                              "Mon_biovol_phase1","Cry_biovol_phase1","Nan_biovol_phase1",
                                              "Ste_biovol_phase1" )], na.rm=TRUE)
datbvrel$Total_Biovol2 <- rowSums(datbvrel[,c("Syn_biovol_phase2","Ana_biovol_phase2", "Acu_biovol_phase2",
                                              "Mon_biovol_phase2","Cry_biovol_phase2","Nan_biovol_phase2",
                                              "Ste_biovol_phase2")], na.rm=TRUE)

datbvdrellong <- datbvrel %>% 
  pivot_longer(cols = c(6:19),names_to = "Species", values_to = "Biovolume")%>% #switch columns to rows
  group_by(Community, Medium,NP_medium, Treatment, Species,Total_Biovol1, Total_Biovol2)%>%
  summarise(Biovolume_mean = mean(Biovolume, na.rm = TRUE))
datbvdrellong$phase <- rep_len(c(1,1,1,2,2,2), 1512) #add respective phase as column

datbvdrellong$Treatment <- as.factor(datbvdrellong$Treatment) 
datbvdrellong$Treatment <- factor(datbvdrellong$Treatment, levels=c("Ctrl","P","N","N&P")) 
datbvdrellong$Community <- as.factor(datbvdrellong$Community) 
datbvdrellong$Community <- factor(datbvdrellong$Community, levels=c("1","2","3"))
datbvdrellong$phase <- as.factor(datbvdrellong$phase)

datbvdrellong$Species <- factor(datbvdrellong$Species, 
                                levels=c("Syn_biovol_phase1","Ana_biovol_phase1","Acu_biovol_phase1",
                                         "Mon_biovol_phase1","Cry_biovol_phase1","Nan_biovol_phase1",
                                         "Ste_biovol_phase1","Syn_biovol_phase2","Ana_biovol_phase2", 
                                         "Acu_biovol_phase2","Mon_biovol_phase2","Cry_biovol_phase2",
                                         "Nan_biovol_phase2","Ste_biovol_phase2"))
levels(datbvdrellong$Species)<- c("S. elongatus 1","A. variabilis 1","A. obliquus 1", "M. minutum 1", 
                                 "C. ovata 1","N. limnetica 1", "S. hantzschii 1", "S. elongatus 2",
                                 "A. variabilis 2","A. obliquus 2", "M. minutum 2", "C. ovata 2",
                                 "N. limnetica 2","S. hantzschii 2")
#change name of Species to make the graphical representation (legend) look better
levels(datbvdrellong$Species)[levels(datbvdrellong$Species) %in%
                                c('S. elongatus 1', 'S. elongatus 2')] <- 'S. elongatus'
levels(datbvdrellong$Species)[levels(datbvdrellong$Species) %in%
                               c('A. variabilis 1', 'A. variabilis 2')] <- 'A. variabilis'
levels(datbvdrellong$Species)[levels(datbvdrellong$Species) %in%
                               c('A. obliquus 1', 'A. obliquus 2')] <- 'A. obliquus'
levels(datbvdrellong$Species)[levels(datbvdrellong$Species) %in%
                               c('M. minutum 1', 'M. minutum 2')] <- 'M. minutum'
levels(datbvdrellong$Species)[levels(datbvdrellong$Species) %in%
                               c('C. ovata 1', 'C. ovata 2')] <- 'C. ovata'
levels(datbvdrellong$Species)[levels(datbvdrellong$Species) %in%
                               c('N. limnetica 1', 'N. limnetica 2')] <- 'N. limnetica'
levels(datbvdrellong$Species)[levels(datbvdrellong$Species) %in%
                               c('S. hantzschii 1', 'S. hantzschii 2')] <- 'S. hantzschii'

datbvdrellong1<-datbvdrellong %>% 
  filter(Community == "1", Species != "A. obliquus",
         Species !="M. minutum")# exclude green algae not in the community

datbvdrellong1$NP_medium <- factor(datbvdrellong1$NP_medium, levels=c("17.5","35","70")) # give specific order to the factor levels
levels(datbvdrellong1$NP_medium)<- c("Medium N:P = 17.5","Medium N:P = 35","Medium N:P = 70")

BV1<-ggplot(datbvdrellong1,
            aes(phase, Biovolume_mean, fill = Species))+
  geom_bar(position = "fill",stat = "identity",)+
  scale_fill_manual(values=c("steelblue", "powderblue", # "lightgreen","forestgreen",
                                                 "peru","goldenrod","firebrick"))+
  theme_bw()+theme(panel.grid.major.x = element_blank(), panel.grid.minor.x = element_blank(), 
                   panel.grid.minor.y = element_blank(),legend.position="bottom",
                   legend.text = element_text(size=9), legend.title = element_text(size=10))+
  labs(x = "Experimental phase", y = "Relative biovolume", title = "Community 1")+
  facet_grid2(Treatment~NP_medium, strip = stripGRIDBrel, scales = "free_y")+
  guides(fill=guide_legend(nrow=3,byrow=TRUE))# 5 x 5

datbvdrellong2<-datbvdrellong %>% filter(Community == "2", Species != "C. ovata",
                                         Species !="N. limnetica",
                                         Species !="S. hantzschii")# exclude other species not in the community
datbvdrellong2$NP_medium <- factor(datbvdrellong2$NP_medium, levels=c("17.5","35","70")) # give specific order to the factor levels
levels(datbvdrellong2$NP_medium)<- c("Medium N:P = 17.5","Medium N:P = 35","Medium N:P = 70")

BV2<- ggplot(datbvdrellong2,
            aes(phase, Biovolume_mean, fill = Species))+
  geom_bar(position = "fill",stat = "identity")+
  scale_fill_manual(values=c("steelblue", "powderblue", "seagreen","darkgreen"
                             #"peru","goldenrod","firebrick"
                             ))+
  theme_bw()+theme(panel.grid.major.x = element_blank(), panel.grid.minor.x = element_blank(), 
                   panel.grid.minor.y = element_blank(),legend.position="bottom",
                   legend.text = element_text(size=9), legend.title = element_text(size=10))+
  labs(x = "Experimental phase", y = "Relative biovolume",title = "Community 2")+
  facet_grid2(Treatment~NP_medium, strip = stripGRIDBrel, scales = "free_y")+
  guides(fill=guide_legend(nrow=2,byrow=TRUE))# 5 x 5

datbvdrellong3<-datbvdrellong %>% filter(Community == "3") #all species
datbvdrellong3$NP_medium <- factor(datbvdrellong3$NP_medium, levels=c("17.5","35","70")) # give specific order to the factor levels
levels(datbvdrellong3$NP_medium)<- c("Medium N:P = 17.5","Medium N:P = 35","Medium N:P = 70")

BV3<-ggplot(datbvdrellong3,
            aes(phase, Biovolume_mean, fill = Species))+
  geom_bar(position = "fill",stat = "identity")+
  scale_fill_manual(values=c("steelblue", "powderblue", "seagreen","darkgreen","peru","goldenrod","firebrick"))+
  theme_bw()+theme(panel.grid.major.x = element_blank(), panel.grid.minor.x = element_blank(), 
                   panel.grid.minor.y = element_blank(),legend.position="bottom",
                   legend.text = element_text(size=9), legend.title = element_text(size=10))+
  labs(x = "Experimental phase", y = "Relative biovolume",title = "Community 3")+
  facet_grid2(Treatment~NP_medium, strip = stripGRIDBrel, scales = "free_y")+
  guides(fill=guide_legend(nrow=3,byrow=TRUE))# 5 x 5

ggarrange(BV1, BV2, BV3, ncol = 3, nrow = 1,align = "hv")

###Tukey's tests - Biovolume####
#Synechococcus - DAY 43 - C1####
sub.dat <- filter(datbvsp2, Species == "S. elongatus", Community == 1, NP_medium == "17.5")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group #single N/serial N a ab b b

sub.dat <- filter(datbvsp2, Species == "S. elongatus", Community == 1, NP_medium == "35")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group #simultaneous a a a b

sub.dat <- filter(datbvsp2, Species == "S. elongatus", Community == 1, NP_medium == "70")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group #simultaneous a a a b

#Synechococcus - DAY 43 - C2####
sub.dat <- filter(datbvsp2, Species == "S. elongatus", Community == 2, NP_medium == "17.5")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # a a a a

sub.dat <- filter(datbvsp2, Species == "S. elongatus", Community == 2, NP_medium == "35")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # a a a a

sub.dat <- filter(datbvsp2, Species == "S. elongatus", Community == 2, NP_medium == "70")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group #single P a b a ab  

#Synechococcus - DAY 43 - C3 ####
sub.dat <- filter(datbvsp2, Species == "S. elongatus", Community == 3, NP_medium == "17.5")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # a a a a

sub.dat <- filter(datbvsp2, Species == "S. elongatus", Community == 3, NP_medium == "35")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # a a a a

sub.dat <- filter(datbvsp2, Species == "S. elongatus", Community == 3, NP_medium == "70")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # a a a a 

#Acutodesmus - DAY 43 - C2 ####
sub.dat <- filter(datbvsp2, Species == "A. obliquus", Community == 2, NP_medium == "17.5")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # single N a a b b

sub.dat <- filter(datbvsp2, Species == "A. obliquus", Community == 2, NP_medium == "35",
                  sample != "40")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # single N a a b b

sub.dat <- filter(datbvsp2, Species == "A. obliquus", Community == 2, NP_medium == "70")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # single N a a ab ab

#Acutodesmus - DAY 43 - C3 ####
sub.dat <- filter(datbvsp2, Species == "A. obliquus", Community == 3, NP_medium == "17.5")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # single N a a b b

sub.dat <- filter(datbvsp2, Species == "A. obliquus", Community == 3, NP_medium == "35")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # single N a ab b b

sub.dat <- filter(datbvsp2, Species == "A. obliquus", Community == 3, NP_medium == "70")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # single N a a a a

#Monoraphidium - DAY 43 - C2 ####
sub.dat <- filter(datbvsp2, Species == "M. minutum", Community == 2, NP_medium == "17.5")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group #  a a a a

sub.dat <- filter(datbvsp2, Species == "M. minutum", Community == 2, NP_medium == "35",
                  sample != "40")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # single N a a b ab

sub.dat <- filter(datbvsp2, Species == "M. minutum", Community == 2, NP_medium == "70")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # single N a a b b

#Monoraphidium - DAY 43 - C3 ####
sub.dat <- filter(datbvsp2, Species == "M. minutum", Community == 3, NP_medium == "17.5")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # single N a a b b

sub.dat <- filter(datbvsp2, Species == "M. minutum", Community == 3, NP_medium == "35")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # a a a a

sub.dat <- filter(datbvsp2, Species == "M. minutum", Community == 3, NP_medium == "70")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # a a a a

#Nannochloropsis - DAY 43 - C1####
sub.dat <- filter(datbvsp2, Species == "N. limnetica", Community == 1, NP_medium == "17.5")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group #  a a a a

sub.dat <- filter(datbvsp2, Species == "N. limnetica", Community == 1, NP_medium == "35")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # a a a a

sub.dat <- filter(datbvsp2, Species == "N. limnetica", Community == 1, NP_medium == "70")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # a a a a

#Nannochloropsis - DAY 43 - C3 ####
sub.dat <- filter(datbvsp2, Species == "N. limnetica", Community == 3, NP_medium == "17.5")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group #  a a a a

sub.dat <- filter(datbvsp2, Species == "N. limnetica", Community == 3, NP_medium == "35")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # a a a a

sub.dat <- filter(datbvsp2, Species == "N. limnetica", Community == 3, NP_medium == "70")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # a a a a

#Total biovolume - DAY 43 - C1 ####
sub.dat <- filter(datbvsp2, Species == "Total Biovolume", Community == 1, NP_medium == "17.5")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group #  single N a ab b b

sub.dat <- filter(datbvsp2, Species == "Total Biovolume",Community == 1, NP_medium == "35")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # simultaneous co-lim a a a b

sub.dat <- filter(datbvsp2, Species == "Total Biovolume",Community == 1, NP_medium == "70")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # simultaneous co-lim a a a b


#Total biovolume - DAY 43 - C2 ####
sub.dat <- filter(datbvsp2, Species == "Total Biovolume", Community == 2, NP_medium == "17.5")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # single N a a b b

sub.dat <- filter(datbvsp2, Species == "Total Biovolume", Community == 2, NP_medium == "35",
                  sample != "40")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # single N a a b b

sub.dat <- filter(datbvsp2, Species == "Total Biovolume", Community == 2, NP_medium == "70")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # single N a ab b b

#Total biovolume - DAY 43 - C3 ####
sub.dat <- filter(datbvsp2, Species == "Total Biovolume", Community == 3, NP_medium == "17.5")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group #  single N a a b b

sub.dat <- filter(datbvsp2, Species == "Total Biovolume", Community == 3, NP_medium == "35")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
HSD.test(aov(lmod), "Treatment", console=F)$group # single a a b b

sub.dat <- filter(datbvsp2, Species == "Total Biovolume", Community == 3, NP_medium == "70")
sub.dat$Treatment <- factor(sub.dat$Treatment, levels=c("Ctrl","P","N","N&P"))
levels(sub.dat$Treatment)<- c("Ctrl","P","N","NP") #set N&P to NP
lmod <- lm(Biovolume~Treatment, data= sub.dat)
anova(lmod)
HSD.test(aov(lmod), "Treatment", console=F)$group # a a a a

